@@ -1,33 +1,9 @@
-/////////////////////////////////////////////////////////////////////////////
-//
-// Project:     SMB kioslave for KDE2
-//
-// File:        smburl.cpp
-//
-// Abstract:    Utility class implementation used by SMBSlave
-//
-// Author(s):   Matthew Peterson <mpeterson@caldera.com>
-//
-//---------------------------------------------------------------------------
-//
-// Copyright (c) 2000  Caldera Systems, Inc.
-// Copyright (c) 2020  Harald Sitter <sitter@kde.org>
-//
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2.1 of the License, or
-// (at your option) any later version.
-//
-//     This program is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU Lesser General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with this program; see the file COPYING.  If not, please obtain
-//     a copy from https://www.gnu.org/copyleft/gpl.html
-//
-/////////////////////////////////////////////////////////////////////////////
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2000 Caldera Systems, Inc.
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
+    SPDX-FileContributor: Matthew Peterson <mpeterson@caldera.com>
+*/
 
 #include "smburl.h"
 #include "smb-logsettings.h"
